@@ -1,8 +1,8 @@
 ea1 <-
-function (data, design=1, alpha=0.05, list=FALSE) 
+function (data, design=1, alpha=0.05, list=FALSE, p.adjust=1, plot=2) 
 {
     list=ifelse(list==FALSE,1,2)
-    
+
 sk=function(means, df1, QME, nrep, alpha=0.05){
 sk1=function(means, df1, QME, nrep, alpha=alpha) {
 means=sort(means,decreasing=TRUE)
@@ -72,7 +72,12 @@ return(rp2)
     }
         fr=function(m,data){
         r=resid(m)
-        s <- shapiro.test(r)
+	i=ifelse(length(r)>5000, 2,1)
+	jr=function(r,aa)r+aa-aa
+	jsample=function(r,aa)sample(r,aa)
+	rr=list(jr,jsample)
+	rr=rr[[i]](r,5000)
+        s <- shapiro.test(rr)
         b <- bartlett.test(response ~ treatments, na.action = na.omit, 
                            data = data)
         cvf = cv(m)
@@ -127,8 +132,11 @@ return(rp2)
         yxx=yi/(si*sqrt(2))
         vt=1-pt(yxx,dff); vt=vt*2
         vt=round(vt,4)
-        ggs=data.frame(w,round(yi,4),st, ssnk, sd, vt)
-        colnames(ggs)=c("pair", "contrast","p(tukey)", "p(snk)", "p(duncan)", "p(t)")
+	lp=list("none","holm", "hochberg", "hommel", "bonferroni", "BH", "BY","fdr")
+	pf=p.adjust(vt, lp[[p.adjust]])
+        ggs=data.frame(w,round(yi,4),st, ssnk, sd, round(pf,4))
+	nam=list("p(t)","p(t)adjust.holm", "p(t)adjust.hochberg", "p(t)adjust.hommel", "p(t)adjust.bonferroni", "p(t)adjust.BH", "p(t)adjust.BY","p(t)adjust.fdr")
+        colnames(ggs)=c("pair", "contrast","p(tukey)", "p(snk)", "p(duncan)", nam[[p.adjust]])
         return(ggs)
     }
 
@@ -314,10 +322,32 @@ return(rp2)
         jjj2=inab(x2, decreasing = decreasing,); jjj2=jjj2[[1]]
         jjj3=inab(x3, decreasing = decreasing,); jjj3=jjj3[[1]]
         jjj4=inab(x4, decreasing = decreasing,); jjj4=jjj4[[1]]
-        hgy=data.frame(jjj1,jjj2,jjj3,jjj4); names(hgy)=c("tukey","snk","duncan","t")
+	nam=list("t","t.adjust.holm", "t.adjust.hochberg", "t.adjust.hommel", "t.adjust.bonferroni", "t.adjust.BH", "t.adjust.BY","t.adjust.fdr")
+        hgy=data.frame(jjj1,jjj2,jjj3,jjj4); names(hgy)=c("tukey","snk","duncan",nam[[p.adjust]])
         return(hgy)
     }
-    
+
+	pres=function(m){
+	r=resid(m)
+	r=scale(r)
+	t=1:length(r)
+	g1=function(r){boxplot(r,col="grey80",ylab="Standardized residuals", main="Box plot for residuals")}
+	g2=function(r){plot(r~t, pch="",ylim=c(-4,4), ylab="Standardized residuals", xlab="Sequence data", 		main="Standardized residuals vs Sequence data", axes=FALSE);axis(2,c(-4,-3.5,-3,-2.5,-2,-1,0,1,2,2.5,3,3.5,4));abline(h=2.5, lty=2);abline(h=-2.5,lty=2);abline(h=3.5, lty=2, col=2);abline(h=-3.5,lty=2, col=2); text(2.5,2.7, "2.5 z-score");text(2.5,-2.7, "-2.5 z-score");text(2.5,3.7, "3.5 z-score");text(2.5,-3.7, "-3.5 z-score");text(t,r,labels=1:length(r))}
+	a=qqnorm(r,plot.it = FALSE)
+	d=data.frame(a1=a$x,a2=a$y,a3=sqrt((a$y)^2),a4=1:length(r))	
+	do=d[order(d[,3], decreasing=TRUE),]
+d1=do[1,c(1,2)]
+d2=do[2,c(1,2)]
+d3=do[3,c(1,2)]
+n1=as.character(do[1,4])
+n2=as.character(do[2,4])
+n3=as.character(do[3,4])
+	g3=function(r){qqnorm(r, ylab="Standardized residuals", xlab="Theoretical quantiles", main="Standardized residuals vs Theoretical quantiles");qqline(r, col = "grey50");text(d1,n1,adj=-0.5,col=2, cex=0.8);text(d2,n2,adj=-0.5,col=2, cex=0.8);text(d3,n3,adj=-0.5,col=2,cex=0.8)}
+	g=list(g1,g2,g3)
+	g[[plot]](r)
+	}
+
+	    
     f1 = function(data) {
         names(data) = c("treatments", "response")
         data <- data.frame(treatments = factor(data$treatments), 
@@ -344,7 +374,8 @@ return(rp2)
         l <- list(a, mf, test, res)
         names(l) = list("Analysis of variance",  
                         "Means", "Multiple comparison test", "Residual analysis")
-        return(l)
+      	pres(m)  
+	return(l)
     }	
     
     f2 <- function(data) {
@@ -378,6 +409,7 @@ return(rp2)
         l <- list(a3,mf, test, res)
         names(l) = list("Analysis of variance",  
                         "Adjusted means", "Multiple comparison test", "Residual analysis")
+	pres(m)  
         return(l)}
     f3 <- function(data) {
         names(data) = c("treatments", "rows", "columns", "response")
@@ -413,6 +445,7 @@ return(rp2)
         l <- list(a3,mf, test,res)
         names(l) = list("Analysis of variance",  
                         "Adjusted means", "Multiple comparison test", "Residual analysis")
+	pres(m)  
         return(l)
     }
     
@@ -448,6 +481,7 @@ return(rp2)
         l <- list(a, mf, test, res)
         names(l) = list("Analysis of variance",  
                         "Adjusted means", "Multiple comparison test", "Residual analysis")
+	pres(m)  
         return(l)
     }
     
@@ -486,6 +520,7 @@ return(rp2)
         l<-list(a,mf, test, res)
         names(l) = list("Analysis of variance",  
                         "Adjusted means", "Multiple comparison test", "Residual analysis")
+	pres(m)  
         return(l)}
     
     f6<-function(data){ 
@@ -520,6 +555,7 @@ return(rp2)
         mf=data.frame(ma,groups, scott_knott)
         rownames(mf) = NULL
         l<-list(a,mf, test, res)
+	pres(m)  
         names(l) = list("Analysis of variance",  
                         "Adjusted means", "Multiple comparison test", "Residual analysis")
         return(l)}
@@ -551,6 +587,7 @@ return(rp2)
         l<-list(a,mf, test, res)
         names(l) = list("Analysis of variance",  
                         "Adjusted means", "Multiple comparison test", "Residual analysis")
+	pres(m)  
         return(l)}
     
     f8<-function(data){ 
@@ -581,6 +618,7 @@ return(rp2)
         l<-list(a,s,cvf,mf, test)
         names(l) = list("Analysis of variance",  "Normality test","Coefficient of variation (%)",
                         "Adjusted means", "Multiple comparison test")
+		pres(m)  
         return(l)}
     
     f9<-function(data){ 
@@ -609,12 +647,14 @@ return(rp2)
         l<-list(a,mf, test, res)
         names(l) = list("Analysis of variance",  
                         "Adjusted means", "Multiple comparison test", "Residual analysis")
+	pres(m)  
         return(l)}
     
     f10<-function(data){ 
         names(data)=c("treatments","repetition", "blocks", "response")
         data<-data.frame(treatments=factor(data$treatments), repetition=factor(data$repetition), blocks=factor(data$blocks), response=data$response)
         m<-aov(response~repetition/blocks+treatments,data=data, contrasts=list(repetition=contr.sum, blocks=contr.sum, treatments=contr.sum))
+	mrr=m
         m1<-aov(response~-1+treatments+repetition/blocks,data=data, contrasts=list(repetition=contr.sum, blocks=contr.sum, treatments=contr.sum))
         a2<-Anova(m, type=3) 
         a3<-a2[-1,]
@@ -644,6 +684,7 @@ return(rp2)
         Ef=100*QMEB/vef
         l<-list(a3,round(vef,4), round(Ef,4), mf,test, res)
         names(l)= list("Analysis of variance", "Effective variance", "Efficiency of the design (%)","Adjusted means", "Multiple comparison test", "Residual analysis")
+	pres(mrr)  
         return(l)}
     
     f11<-function(data){ 
@@ -652,6 +693,7 @@ return(rp2)
         block=interaction(data$repetition,data$blocks)
         data=data.frame(data,block)
         m<-lme(response~ repetition +treatments,random=~1|block, data=data, contrasts=list(repetition=contr.sum, treatments=contr.sum), na.action=na.omit)
+	mrr=m
         m1<-lme(response~-1+treatments+repetition, random=~1|repetition/blocks,data=data, contrasts=list(repetition=contr.sum, blocks=contr.sum, treatments=contr.sum), na.action=na.omit)
         a3<-anova(m, type="marginal")
         a3<-a3[-1,]
@@ -683,6 +725,7 @@ return(rp2)
         Ef=100*(deviance(mbb)/df.residual(mbb))/vef
         l<-list(a3,s,b1, round(vef,4), round(Ef,4), mf,test)
         names(l)= list("Analysis of variance (marginal anova = type III SS)", "Normality test", "Homogeneity of variances", "Effective variance", "Efficiency of the design (%)","Adjusted means", "Multiple comparison test")
+		pres(mrr)  
         return(l)}
     
     f12<-function(data){
@@ -718,6 +761,7 @@ return(rp2)
         rownames(mf) = NULL
         l<-list(a,mf, test, res)
         names(l)= list("Analysis of variance", "Adjusted means", "Multiple comparison test","Residual analysis")
+	pres(m)  
         return(l)}
     
     f13<-function(data){
@@ -754,6 +798,7 @@ return(rp2)
         rownames(mf) = NULL
         l<-list(a,mf, test, res)
         names(l)= list("Analysis of variance", "Adjusted means", "Multiple comparison test","Residual analysis")
+	pres(m)  
         return(l)}
 
 f14 <-
@@ -794,7 +839,8 @@ yi=auxj[1,]-auxj[2,]#names
 jjj=ma[,3]
 auxjj <- combn(jjj, 2)
 yii=(1/auxjj[1,])+(1/auxjj[2,])#means for ranks
-ct=S*((nn-1-ra2)/(nn-nlevels(data$treatments)))#???? o valor de T (ra2) pode causar valor negativo?
+ct=S*((nn-1-ra2)/(nn-nlevels(data$treatments)))
+x=1:length(yi)
 f4=function(x){yi[x]/sqrt(ct*yii[x])}
 tcal=lapply(x, f4)
 p=function(x){(1-pt(tcal[[x]],df=nn-nlevels(data$treatments)))*2}
@@ -814,6 +860,8 @@ med
 pri=data.frame(round(c(ra2,pq),4));colnames(pri)="Estimates"
 rownames(pri)=c("Kruskal-Wallis chi-squared = ","p.value = ")
 l=list(pri,med,resp) ; names(l)=c("Kruskal-Wallis Rank Sum Test", "Ranks, Means and Medians", "Multiple comparison test for ranks")
+n=2:(nlevels(data$treatments)+1)
+plot(response~treatments, data=data, col=n)
 return(l)
 }
 
@@ -825,57 +873,51 @@ d = split(data, data[,2])
 f1=function(data){rank(data$response, ties.method = c("average"))}
 ran=lapply(d, f1)
 da=data.frame(ran)
+rownames(da)=d[[1]]$treatments
 su=rowSums(da, na.rm=TRUE); sua=su^2; suu=sum(sua)
 b=nlevels(data[,2])
 t=nlevels(data[,1])
 gl=t-1
 cal=((12/(b*t*(t+1)))*(suu))-(3*b*(t+1))
 pq=pchisq(cal,lower.tail=FALSE, df=gl) #chisq
-
-
-ru=rep(su, rep(b,t))
-data2=data.frame(data[,c(1,3)],ru)
-
-a1=aggregate(.~treatments, data2, FUN=mean)
-a2=aggregate(.~treatments, data2, FUN=median)
-
-da=data.frame(names=levels(a1$treatments), ra=a1[,3], means=a1[,2],md=a2[,2])
+f11=function(data){mean(data$response, na.rm=TRUE)}
+ran2=lapply(d, f11)
+so=data.frame(su, na=names(su))
+so=so[order(so[,2], decreasing=FALSE),]
+a1=aggregate(.~treatments, data, FUN=mean)
+a2=aggregate(.~treatments, data, FUN=median)
+da=data.frame(names=levels(a1$treatments), ra=so[,1], means=a1[,3],md=a2[,3])
 ma=da[order(da[,2], decreasing=TRUE),]
-
 j=ma[,1];j=as.character(j)
 aux <- combn(j, 2)
 w <- apply(aux, 2, paste, collapse = " - ")
 jj=ma[,2]
 auxj <- combn(jj, 2)
 yi=auxj[1,]-auxj[2,]
-
 dm=sqrt(b*t*(t+1)/6)
-
 valores=yi/dm
 prob=1-pnorm(valores)
 prob1=prob*2
 prob2=p.adjust(prob1, method="holm")
 prob3=p.adjust(prob1, method="bonferroni")
 prob4=p.adjust(prob1, method="fdr")
-
 resp=data.frame(w,round(yi,4),round(prob1,4), round(prob2,4), round(prob3,4), round(prob4,4))
 resp
 colnames(resp)=c("pair", "contrast", "p(non adjusted)" ,"p.adj(Holm)", "p.adj(Bonferroni)", "p.adj(fdr)")
 med=ft(resp, alpha=alpha)
-
 colnames(med)=c("non adjusted", "adjust.Holm", "adjust.Bonferroni", "adjust.fdr" ) 
-
-
 med=data.frame(treatment=rownames(med),rank=round(ma$ra,4), mean=round(ma$means,4), median=round(ma$md,4),med)
 rownames(med)=NULL
 med
 pri=data.frame(round(c(cal,pq),4));colnames(pri)="Estimates"
 rownames(pri)=c("Friedman chi-squared = ","p.value = ")
 l=list(pri,med,resp) ; names(l)=c("Friedman Rank Sum Test", "Ranks, Means and Medians", "Multiple comparison test for ranks")
+n=2:(nlevels(data$treatments)+1)
+plot(response~treatments, data=data, col=n)
 return(l)
 }
 
-    
+   
     de1=c(1); de2=c(1,2);de3=c(1,2,3);de4=c(1,2,3,4);de5=c(1,2);de6=c(1,2,3)
     de7=c(1,2,3); de8=c(1,2); de9=c(1,2,3); de10=c(1,2,3);de11=c(1,2,3);de12=c(1,2,3);de13=c(1,2,3,4)
     de14=c(1);de15=c(1,2)
@@ -896,3 +938,6 @@ return(l)
     li=li[[list]]
     return(li)
 }
+
+
+
